"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeRaw = exports.make = exports.handler = void 0;
var internal = /*#__PURE__*/_interopRequireWildcard(/*#__PURE__*/require("./internal/node-testing.js"));
function _getRequireWildcardCache(e) {
  if ("function" != typeof WeakMap) return null;
  var r = new WeakMap(),
    t = new WeakMap();
  return (_getRequireWildcardCache = function (e) {
    return e ? t : r;
  })(e);
}
function _interopRequireWildcard(e, r) {
  if (!r && e && e.__esModule) return e;
  if (null === e || "object" != typeof e && "function" != typeof e) return {
    default: e
  };
  var t = _getRequireWildcardCache(r);
  if (t && t.has(e)) return t.get(e);
  var n = {
      __proto__: null
    },
    a = Object.defineProperty && Object.getOwnPropertyDescriptor;
  for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) {
    var i = a ? Object.getOwnPropertyDescriptor(e, u) : null;
    i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u];
  }
  return n.default = e, t && t.set(e, n), n;
}
/**
 * Create a testing client for the `Server`.
 *
 * @category constructors
 * @since 1.0.0
 */
const make = exports.make = internal.make;
/**
 * Create a testing client for the `Server`. Instead of the `Client.Client` interface
 * it returns a raw *@effect/platform/Http/Client* `Client` with base url set.
 *
 * @category constructors
 * @since 1.0.0
 */
const makeRaw = exports.makeRaw = internal.makeRaw;
/**
 * Testing of `Handler.Handler<A, E, R>`.
 *
 * @example
 * import { HttpClientRequest } from "@effect/platform"
 * import { Schema } from "effect"
 * import { Effect } from "effect"
 * import { Api, Handler } from "effect-http"
 * import { NodeTesting } from "effect-http-node"
 *
 * const myEndpoint = Api.get("myEndpoint", "/my-endpoint").pipe(
 *   Api.setResponseBody(Schema.Struct({ hello: Schema.String }))
 * )
 *
 * const myHandler = Handler.make(myEndpoint, () => Effect.succeed({ hello: "world" }))
 *
 * Effect.gen(function*() {
 *   const client = yield* NodeTesting.handler(myHandler)
 *   const response = yield* client.execute(HttpClientRequest.get("/my-endpoint"))
 *
 *   assert.deepStrictEqual(response.status, 200)
 *   assert.deepStrictEqual(yield* response.json, { hello: "world" })
 * }).pipe(Effect.scoped, Effect.runFork)
 *
 * @category constructors
 * @since 1.0.0
 */
const handler = exports.handler = internal.handler;
//# sourceMappingURL=NodeTesting.js.map