import * as internal from "./internal/node-testing.js";
/**
 * Create a testing client for the `Server`.
 *
 * @category constructors
 * @since 1.0.0
 */
export const make = internal.make;
/**
 * Create a testing client for the `Server`. Instead of the `Client.Client` interface
 * it returns a raw *@effect/platform/Http/Client* `Client` with base url set.
 *
 * @category constructors
 * @since 1.0.0
 */
export const makeRaw = internal.makeRaw;
/**
 * Testing of `Handler.Handler<A, E, R>`.
 *
 * @example
 * import { HttpClientRequest } from "@effect/platform"
 * import { Schema } from "effect"
 * import { Effect } from "effect"
 * import { Api, Handler } from "effect-http"
 * import { NodeTesting } from "effect-http-node"
 *
 * const myEndpoint = Api.get("myEndpoint", "/my-endpoint").pipe(
 *   Api.setResponseBody(Schema.Struct({ hello: Schema.String }))
 * )
 *
 * const myHandler = Handler.make(myEndpoint, () => Effect.succeed({ hello: "world" }))
 *
 * Effect.gen(function*() {
 *   const client = yield* NodeTesting.handler(myHandler)
 *   const response = yield* client.execute(HttpClientRequest.get("/my-endpoint"))
 *
 *   assert.deepStrictEqual(response.status, 200)
 *   assert.deepStrictEqual(yield* response.json, { hello: "world" })
 * }).pipe(Effect.scoped, Effect.runFork)
 *
 * @category constructors
 * @since 1.0.0
 */
export const handler = internal.handler;
//# sourceMappingURL=NodeTesting.js.map