import { createServer } from "http";
import * as NodeContext from "@effect/platform-node/NodeContext";
import * as NodeHttpServer from "@effect/platform-node/NodeHttpServer";
import * as FetchHttpClient from "@effect/platform/FetchHttpClient";
import * as HttpClient from "@effect/platform/HttpClient";
import * as HttpClientRequest from "@effect/platform/HttpClientRequest";
import * as HttpServer from "@effect/platform/HttpServer";
import * as Context from "effect/Context";
import * as Deferred from "effect/Deferred";
import * as Effect from "effect/Effect";
import * as Layer from "effect/Layer";
import * as Client from "effect-http/Client";
import * as Handler from "effect-http/Handler";
import * as NodeSwaggerFiles from "../NodeSwaggerFiles.js";
/** @internal */
const defaultHttpClient = /*#__PURE__*/FetchHttpClient.layer.pipe(Layer.build, /*#__PURE__*/Effect.map(/*#__PURE__*/Context.get(HttpClient.HttpClient)), Effect.scoped, Effect.runSync);
/** @internal */
export const make = (app, api, options) => startTestServer(app).pipe(Effect.map(url => Client.make(api, {
  ...options,
  httpClient: makeHttpClient(options?.httpClient ?? defaultHttpClient, url)
})), Effect.provide(NodeSwaggerFiles.SwaggerFilesLive), Effect.provide(NodeContext.layer));
/** @internal */
export const makeRaw = app => startTestServer(app).pipe(Effect.map(url => makeHttpClient(defaultHttpClient, url)), Effect.provide(NodeSwaggerFiles.SwaggerFilesLive), Effect.provide(NodeContext.layer));
/** @internal */
export const handler = handler => startTestServer(Handler.getRouter(handler)).pipe(Effect.map(url => makeHttpClient(defaultHttpClient, url)), Effect.provide(NodeContext.layer));
/** @internal */
const startTestServer = app => Effect.flatMap(Deferred.make(), allocatedUrl => serverUrl.pipe(Effect.flatMap(url => Deferred.succeed(allocatedUrl, url)), Effect.flatMap(() => Layer.launch(HttpServer.serve(app))), Effect.provide(NodeHttpServer.layer(createServer, {
  port: undefined
})), Effect.forkScoped, Effect.flatMap(() => Deferred.await(allocatedUrl))));
/** @internal */
const makeHttpClient = (client, url) => client.pipe(HttpClient.mapRequest(HttpClientRequest.prependUrl(url)), HttpClient.transformResponse(Effect.mapInputContext(ctx => {
  const init = ctx.unsafeMap.get(FetchHttpClient.RequestInit.key) ?? {};
  return Context.add(ctx, FetchHttpClient.RequestInit, {
    keepalive: false,
    ...init
  });
})));
/** @internal */
const serverUrl = /*#__PURE__*/Effect.map(HttpServer.HttpServer, server => {
  const address = server.address;
  if (address._tag === "UnixAddress") {
    return address.path;
  }
  return `http://localhost:${address.port}`;
});
//# sourceMappingURL=node-testing.js.map